CREATE TABLE hibernate_sequences (
	sequence_name VARCHAR(200) NOT NULL,
	next_val INT NOT NULL,
	PRIMARY KEY (sequence_name)
);

CREATE TABLE SBI_ACTIVITY_MONITORING (
	ID INT NOT NULL,
	ACTION_TIME DATETIME NOT NULL,
	USERNAME VARCHAR(40) NOT NULL,
	USERGROUP VARCHAR(400) NULL,
	LOG_LEVEL VARCHAR(10) NULL,
	ACTION_CODE VARCHAR(45) NOT NULL,
	INFO VARCHAR(400) NULL,
	PRIMARY KEY (ID)
);

CREATE TABLE SBI_ALERT (
	ID INT NOT NULL,
	NAME VARCHAR(40) NOT NULL,
	SINGLE_EXECUTION CHAR(1) NULL,
	EVENT_BEFORE_TRIGGER_ACTION INT NULL,
	LISTENER_ID INT NOT NULL,
	LISTENER_OPTIONS VARCHAR(4000) NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL DEFAULT NULL,
	TIME_DE DATETIME NULL DEFAULT NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (ID)
);

CREATE TABLE SBI_ALERT_ACTION (
	ID INT NOT NULL,
	NAME VARCHAR(40) NOT NULL,
	CLASS_NAME VARCHAR(200) NOT NULL,
	TEMPLATE VARCHAR(200) NOT NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL DEFAULT NULL,
	TIME_DE DATETIME NULL DEFAULT NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (ID)
);

CREATE TABLE SBI_ALERT_LISTENER (
	ID INT NOT NULL,
	NAME VARCHAR(40) NOT NULL,
	CLASS_NAME VARCHAR(200) NOT NULL,
	TEMPLATE VARCHAR(200) NOT NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL DEFAULT NULL,
	TIME_DE DATETIME NULL DEFAULT NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (ID)
);

CREATE TABLE SBI_ALERT_LOG (
	ID INT NOT NULL,
	LISTENER_ID INT NOT NULL,
	ACTION_ID INT NULL,
	LISTENER_PARAMS VARCHAR(4000) NULL,
	ACTION_PARAMS VARCHAR(4000) NULL,
	DETAIL VARCHAR(4000) NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL DEFAULT NULL,
	TIME_DE DATETIME NULL DEFAULT NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (ID)
);

CREATE TABLE SBI_ARTIFACTS (
	ID INT NOT NULL,
	NAME VARCHAR(100) NOT NULL,
	DESCR VARCHAR(500) NULL,
	TYPE VARCHAR(50) NULL,
	MODEL_LOCKED BIT NULL,
	MODEL_LOCKER VARCHAR(100) NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (ID)
);

CREATE TABLE SBI_ARTIFACTS_VERSIONS (
	ID INT NOT NULL,
	ARTIFACT_ID INT NOT NULL,
	CONTENT VARBINARY(MAX) NOT NULL,
	NAME VARCHAR(100) NULL,
	PROG INT NULL,
	CREATION_DATE DATETIME NULL,
	CREATION_USER VARCHAR(50) NOT NULL,
	ACTIVE BIT NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NULL DEFAULT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (ID)
);

CREATE TABLE SBI_ATTRIBUTE (
	ATTRIBUTE_NAME VARCHAR(255) NOT NULL,
	DESCRIPTION VARCHAR(500) NOT NULL,
	ATTRIBUTE_ID INT NOT NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (ATTRIBUTE_ID)
);

CREATE TABLE SBI_AUDIT (
	ID INT NOT NULL,
	USERNAME VARCHAR(40) NOT NULL,
	USERGROUP VARCHAR(100) NULL,
	DOC_REF INT NULL,
	DOC_ID INT NULL,
	DOC_LABEL VARCHAR(200) NOT NULL,
	DOC_NAME VARCHAR(200) NOT NULL,
	DOC_TYPE VARCHAR(20) NOT NULL,
	DOC_STATE VARCHAR(20) NOT NULL,
	DOC_PARAMETERS TEXT NULL,
	SUBOBJ_REF INT NULL,
	SUBOBJ_ID INT NULL,
	SUBOBJ_NAME VARCHAR(50) NULL,
	SUBOBJ_OWNER VARCHAR(50) NULL,
	SUBOBJ_ISPUBLIC SMALLINT NULL,
	ENGINE_REF INT NULL,
	ENGINE_ID INT NULL,
	ENGINE_LABEL VARCHAR(40) NOT NULL,
	ENGINE_NAME VARCHAR(40) NOT NULL,
	ENGINE_TYPE VARCHAR(20) NOT NULL,
	ENGINE_URL VARCHAR(400) NULL,
	ENGINE_DRIVER VARCHAR(400) NULL,
	ENGINE_CLASS VARCHAR(400) NULL,
	REQUEST_TIME DATETIME NOT NULL,
	EXECUTION_START DATETIME NULL,
	EXECUTION_END DATETIME NULL,
	EXECUTION_TIME INT NULL,
	EXECUTION_STATE VARCHAR(20) NULL,
	ERROR SMALLINT NULL,
	ERROR_MESSAGE VARCHAR(400) NULL,
	ERROR_CODE VARCHAR(20) NULL,
	EXECUTION_MODALITY VARCHAR(40) NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NULL DEFAULT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (ID)
);

CREATE TABLE SBI_AUTHORIZATIONS (
	ID INT NOT NULL,
	NAME VARCHAR(200) NULL,
	PRODUCT_TYPE_ID INT NOT NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (ID)
);

CREATE TABLE SBI_AUTHORIZATIONS_ROLES (
	AUTHORIZATION_ID INT NOT NULL,
	ROLE_ID INT NOT NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (AUTHORIZATION_ID,ROLE_ID)
);

CREATE TABLE SBI_BINARY_CONTENTS (
	BIN_ID INT NOT NULL,
	BIN_CONTENT VARBINARY(MAX) NOT NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (BIN_ID)
);

CREATE TABLE SBI_CACHE_ITEM (
	SIGNATURE VARCHAR(100) NOT NULL,
	NAME TEXT NOT NULL,
	TABLE_NAME VARCHAR(100) NOT NULL,
	DIMENSION DECIMAL(10, 0) NULL,
	CREATION_DATE DATE NULL,
	LAST_USED_DATE DATE NULL,
	PROPERTIES TEXT NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (SIGNATURE)
);

CREATE TABLE SBI_CATALOG_FUNCTION (
	FUNCTION_ID INT NOT NULL,
	NAME VARCHAR(100) NOT NULL,
	DESCRIPTION TEXT NOT NULL,
	LANGUAGE VARCHAR(100) NOT NULL,
	SCRIPT TEXT NOT NULL,
	OWNER VARCHAR(50) NOT NULL,
	KEYWORDS VARCHAR(255) NULL,
	TYPE VARCHAR(50) NULL,
	LABEL VARCHAR(50) NOT NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (FUNCTION_ID)
);

CREATE TABLE SBI_CHECKS (
	CHECK_ID INT NOT NULL,
	DESCR VARCHAR(160) NULL,
	LABEL VARCHAR(20) NOT NULL,
	VALUE_TYPE_CD VARCHAR(20) NOT NULL,
	VALUE_TYPE_ID INT NOT NULL,
	VALUE_1 VARCHAR(400) NULL,
	VALUE_2 VARCHAR(400) NULL,
	NAME VARCHAR(40) NOT NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (CHECK_ID)
);

CREATE TABLE SBI_COMMUNITY (
	COMMUNITY_ID INTEGER NOT NULL,
	NAME VARCHAR(200) NOT NULL,
	DESCRIPTION VARCHAR(350) NULL,
	OWNER CHAR(100) NOT NULL,
	FUNCT_CODE VARCHAR(40) NULL,
	CREATION_DATE DATETIME NOT NULL DEFAULT getdate(),
	LAST_CHANGE_DATE DATETIME NOT NULL DEFAULT getdate(),
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NULL DEFAULT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (COMMUNITY_ID)
);

CREATE TABLE SBI_COMMUNITY_USERS (
	COMMUNITY_ID INT NOT NULL,
	USER_ID CHAR(100) NOT NULL,
	CREATION_DATE DATETIME NOT NULL DEFAULT getdate(),
	LAST_CHANGE_DATE DATETIME NOT NULL DEFAULT getdate(),
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NULL DEFAULT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (COMMUNITY_ID, USER_ID)
);

CREATE TABLE SBI_CONFIG (
	ID INT NOT NULL,
	LABEL VARCHAR(100) NOT NULL,
	NAME VARCHAR(100) NULL,
	DESCRIPTION VARCHAR(500) NULL,
	IS_ACTIVE BIT DEFAULT 1,
	VALUE_CHECK VARCHAR(1000) NULL,
	VALUE_TYPE_ID INT NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	CATEGORY VARCHAR(50) NULL,
	PRIMARY KEY (ID)
);

CREATE TABLE SBI_CROSS_NAVIGATION (
	ID INT NOT NULL,
	NAME VARCHAR(40) NOT NULL,
	TYPE INT NOT NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (ID)
);

CREATE TABLE SBI_CROSS_NAVIGATION_PAR (
	ID INT NOT NULL,
	CN_ID INT NOT NULL,
	FROM_KEY INT NOT NULL,
	TO_KEY INT NOT NULL,
	FROM_TYPE INT NOT NULL,
	FIXED_VALUE VARCHAR(100) NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (ID)
);

CREATE TABLE SBI_DATA_SET (
	DS_ID INT NOT NULL,
	VERSION_NUM INT NOT NULL,
	ACTIVE BIT NOT NULL,
	DESCR VARCHAR(160) NULL,
	LABEL VARCHAR(50) NOT NULL,
	NAME VARCHAR(50) NOT NULL,
	OBJECT_TYPE VARCHAR(50) NULL,
	DS_METADATA TEXT NULL,
	PARAMS VARCHAR(4000) NULL,
	CATEGORY_ID INT NULL,
	TRANSFORMER_ID INT NULL,
	PIVOT_COLUMN VARCHAR(50) NULL,
	PIVOT_ROW VARCHAR(50) NULL,
	PIVOT_VALUE VARCHAR(50) NULL,
	NUM_ROWS BIT DEFAULT 0,
	IS_PERSISTED BIT DEFAULT 0,
	IS_PERSISTED_HDFS BIT DEFAULT 0,
	PERSIST_TABLE_NAME VARCHAR(50) NULL,
	CONFIGURATION TEXT NULL,
	FEDERATION_ID INT NULL,
	OWNER VARCHAR(50) NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NOT NULL,
	SCOPE_ID INT NULL,
	PRIMARY KEY (DS_ID, VERSION_NUM, ORGANIZATION)
);

CREATE TABLE SBI_DATA_SET_FEDERATION (
	FEDERATION_ID INT NOT NULL,
	DS_ID INT NOT NULL,
	VERSION_NUM INT NOT NULL,
	ORGANIZATION VARCHAR(20) NOT NULL,
	PRIMARY KEY (FEDERATION_ID, DS_ID, VERSION_NUM,ORGANIZATION)
);

CREATE TABLE SBI_DATA_SOURCE (
	DS_ID INT NOT NULL,
	DESCR VARCHAR(160) NULL,
	LABEL VARCHAR(50) NOT NULL,
	JNDI VARCHAR(50) NULL,
	URL_CONNECTION VARCHAR(500) NULL,
	USERNAME VARCHAR(50) NULL,
	PWD VARCHAR(50) NULL,
	DRIVER VARCHAR(160) NULL,
	DIALECT_ID INT NOT NULL,
	MULTI_SCHEMA BIT DEFAULT 0,
	ATTR_SCHEMA VARCHAR(45) NULL,
	READ_ONLY BIT DEFAULT 0,
	WRITE_DEFAULT BIT DEFAULT 0,
	JDBC_ADVANCED_CONFIGURATION	VARCHAR(4000),
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL DEFAULT NULL,
	TIME_DE DATETIME NULL DEFAULT NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (DS_ID)
);

CREATE TABLE SBI_DIST_LIST (
	DL_ID INT NOT NULL,
	NAME VARCHAR(40) NOT NULL,
	DESCR VARCHAR(160) NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (DL_ID)
);

CREATE TABLE SBI_DIST_LIST_OBJECTS (
	REL_ID INT NOT NULL,
	DOC_ID INT NOT NULL,
	DL_ID INT NOT NULL,
	XML VARCHAR(5000) NOT NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (REL_ID)
);

CREATE TABLE SBI_DIST_LIST_USER (
	DLU_ID INT NOT NULL,
	LIST_ID INT NOT NULL,
	USER_ID VARCHAR(40) NOT NULL,
	E_MAIL VARCHAR(70) NOT NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (DLU_ID)
);

CREATE TABLE SBI_DOMAINS (
	VALUE_ID INT NOT NULL,
	VALUE_CD VARCHAR(100) NULL,
	VALUE_NM VARCHAR(40) NULL,
	DOMAIN_CD VARCHAR(20) NULL,
	DOMAIN_NM VARCHAR(40) NULL,
	VALUE_DS VARCHAR(160) NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (VALUE_ID)
);

CREATE TABLE SBI_ENGINES (
	ENGINE_ID INT NOT NULL,
	ENCRYPT SMALLINT NULL,
	NAME VARCHAR(40) NOT NULL,
	DESCR VARCHAR(160) NULL,
	MAIN_URL VARCHAR(400) NULL,
	SECN_URL VARCHAR(400) NULL,
	OBJ_UPL_DIR VARCHAR(400) NULL,
	OBJ_USE_DIR VARCHAR(400) NULL,
	DRIVER_NM VARCHAR(400) NULL,
	LABEL VARCHAR(40) NOT NULL,
	ENGINE_TYPE INT NOT NULL,
	CLASS_NM VARCHAR(400) NULL,
	BIOBJ_TYPE INT NOT NULL,
	USE_DATASET BIT DEFAULT 0,
	USE_DATASOURCE BIT DEFAULT 0,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (ENGINE_ID)
);

CREATE TABLE SBI_EVENTS (
	ID INT NOT NULL,
	USER_EVENT VARCHAR(40) NOT NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (ID)
);

CREATE TABLE SBI_EVENTS_LOG (
	ID INT NOT NULL,
	USER_EVENT VARCHAR(40) NOT NULL,
	EVENT_DATE DATETIME DEFAULT getdate() NOT NULL,
	DESCR TEXT NOT NULL,
	PARAMS VARCHAR(1000) NULL,
	HANDLER VARCHAR(400) NOT NULL DEFAULT 'it.eng.spagobi.events.handlers.DefaultEventPresentationHandler',
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NULL DEFAULT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (ID)
);

CREATE TABLE SBI_EVENTS_ROLES (
	EVENT_ID INT NOT NULL,
	ROLE_ID INT NOT NULL,
	PRIMARY KEY (EVENT_ID, ROLE_ID)
);

CREATE TABLE SBI_EXPORTERS (
	ENGINE_ID INT NOT NULL,
	DOMAIN_ID INT NOT NULL,
	DEFAULT_VALUE BIT NULL,
	PRIMARY KEY (ENGINE_ID,DOMAIN_ID)
);

CREATE TABLE SBI_EXT_ROLES (
	EXT_ROLE_ID INT NOT NULL,
	NAME VARCHAR(100) NOT NULL,
	DESCR VARCHAR(160) NULL,
	CODE VARCHAR(20) NULL,
	ROLE_TYPE_CD VARCHAR(20) NOT NULL,
	ROLE_TYPE_ID INT NOT NULL,
	IS_PUBLIC BIT DEFAULT 0,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (EXT_ROLE_ID)
);

CREATE TABLE SBI_EXT_ROLES_CATEGORY (
	EXT_ROLE_ID INT NOT NULL,
	CATEGORY_ID INT NOT NULL,
	PRIMARY KEY (EXT_ROLE_ID, CATEGORY_ID)
);

CREATE TABLE SBI_EXT_USER_ROLES (
	ID INT NOT NULL,
	EXT_ROLE_ID INT NOT NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (ID,EXT_ROLE_ID)
);

CREATE TABLE SBI_FEDERATION_DEFINITION (
	FEDERATION_ID INT NOT NULL,
	LABEL VARCHAR(100) NOT NULL,
	NAME VARCHAR(100) NOT NULL,
	DESCRIPTION VARCHAR(100) NULL,
	RELATIONSHIPS TEXT NULL,
	DEGENERATED BIT NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (FEDERATION_ID)
);

CREATE TABLE SBI_FUNC_ROLE (
	ROLE_ID INT NOT NULL,
	FUNCT_ID INT NOT NULL,
	STATE_CD VARCHAR(20) NULL,
	STATE_ID INT NOT NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (FUNCT_ID,STATE_ID,ROLE_ID)
);

CREATE TABLE SBI_FUNCTION_INPUT_DATASET (
	FUNCTION_ID INT NOT NULL,
	DS_ID INT NOT NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (FUNCTION_ID,DS_ID)
);

CREATE TABLE SBI_FUNCTION_INPUT_VARIABLE (
	FUNCTION_ID INT NOT NULL,
	VAR_NAME VARCHAR(100) NOT NULL,
	VAR_VALUE VARCHAR(100) NOT NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (FUNCTION_ID,VAR_NAME)
);

CREATE TABLE SBI_FUNCTION_OUTPUT (
	FUNCTION_ID INT NOT NULL,
	LABEL VARCHAR(100) NOT NULL,
	OUT_TYPE INT NOT NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (FUNCTION_ID,LABEL)
);

CREATE TABLE SBI_FUNCTIONS (
	FUNCT_ID INT NOT NULL,
	FUNCT_TYPE_CD VARCHAR(20) NOT NULL,
	PARENT_FUNCT_ID INT NULL,
	NAME VARCHAR(40) NULL,
	DESCR VARCHAR(160) NULL,
	PATH VARCHAR(400) NULL,
	CODE VARCHAR(40) NOT NULL,
	PROG INT NOT NULL,
	FUNCT_TYPE_ID INT NOT NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (FUNCT_ID)
);

CREATE TABLE SBI_FUNCTIONS_ORGANIZER (
	FUNCT_ID INT NOT NULL,
	PARENT_FUNCT_ID INT NULL,
	NAME VARCHAR(40) NULL,
	DESCR VARCHAR(160) NULL,
	PATH VARCHAR(400) NULL,
	CODE VARCHAR(40) NOT NULL,
	PROG INT NOT NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (FUNCT_ID)
);

CREATE TABLE SBI_GEO_FEATURES (
	FEATURE_ID INT NOT NULL,
	NAME VARCHAR(40) NOT NULL,
	DESCR VARCHAR(160) NULL,
	TYPE VARCHAR(40) NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (FEATURE_ID)
);

CREATE TABLE SBI_GEO_LAYERS (
	LAYER_ID INT NOT NULL,
	LABEL VARCHAR(100) NOT NULL,
	NAME VARCHAR(100) NULL,
	DESCR VARCHAR(100) NULL,
	LAYER_DEFINITION VARBINARY(MAX) NOT NULL,
	TYPE VARCHAR(40) NULL,
	IS_BASE_LAYER BIT DEFAULT 0 NOT NULL,
	GEO_CATEGORY INT NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (LAYER_ID)
);

CREATE TABLE SBI_GEO_MAP_FEATURES (
	MAP_ID INT NOT NULL,
	FEATURE_ID INT NOT NULL,
	SVG_GROUP VARCHAR(40) NULL,
	VISIBLE_FLAG VARCHAR(1) NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (MAP_ID,FEATURE_ID)
);

CREATE TABLE SBI_GEO_MAPS (
	MAP_ID INT NOT NULL,
	NAME VARCHAR(40) NOT NULL,
	DESCR VARCHAR(160) NULL,
	URL VARCHAR(400) NULL,
	FORMAT VARCHAR(40) NULL,
	HIERARCHY_NAME VARCHAR(100) NULL,
	NUM_LEVEL INT NULL,
	MEMBER_NAME VARCHAR(100) NULL,
	BIN_ID INT NOT NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (MAP_ID)
);

CREATE TABLE SBI_GL_ATTRIBUTES (
	ATTRIBUTE_ID INT NOT NULL,
	ATTRIBUTE_CD VARCHAR(30) NULL,
	ATTRIBUTE_NM VARCHAR(100) NULL,
	ATTRIBUTE_DS VARCHAR(500) NULL,
	MANDATORY_FL INT NULL,
	ATTRIBUTES_TYPE VARCHAR(50) NULL,
	DOMAIN VARCHAR(500) NULL,
	FORMAT VARCHAR(30) NULL,
	DISPLAY_TP VARCHAR(30) NULL,
	ATTRIBUTES_ORDER VARCHAR(30) NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (ATTRIBUTE_ID)
);

CREATE TABLE SBI_GL_BNESS_CLS_WLIST (
	WORD_ID INT NOT NULL,
	BC_ID INT NOT NULL,
	COLUMN_NAME VARCHAR(100) NOT NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (BC_ID,WORD_ID,COLUMN_NAME)
);

CREATE TABLE SBI_GL_CONTENTS (
	CONTENT_ID INT NOT NULL,
	GLOSSARY_ID INT NOT NULL,
	PARENT_ID INT NULL,
	CONTENT_CD VARCHAR(30) NULL,
	CONTENT_NM VARCHAR(100) NULL,
	CONTENT_DS VARCHAR(500) NULL,
	DEPTH INT NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (CONTENT_ID)
);

CREATE TABLE SBI_GL_DATASETWLIST (
	WORD_ID INT NOT NULL,
	DS_ID INT NOT NULL,
	COLUMN_NAME VARCHAR(100) NOT NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	VERSION_NUM INT NULL,
	PRIMARY KEY (WORD_ID,DS_ID,COLUMN_NAME)
);

CREATE TABLE SBI_GL_DOCWLIST (
	WORD_ID INT NOT NULL,
	BIOBJ_ID INT NOT NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (BIOBJ_ID,WORD_ID)
);

CREATE TABLE SBI_GL_GLOSSARY (
	GLOSSARY_ID INT NOT NULL,
	GLOSSARY_CD VARCHAR(30) NULL,
	GLOSSARY_NM VARCHAR(100) NULL,
	GLOSSARY_DS VARCHAR(500) NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (GLOSSARY_ID)
);

CREATE TABLE SBI_GL_REFERENCES (
	WORD_ID INT NOT NULL,
	REF_WORD_ID INT NOT NULL,
	REFERENCES_ORDER INT NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (WORD_ID,REF_WORD_ID)
);

CREATE TABLE SBI_GL_TABLE_WLIST (
	WORD_ID INT NOT NULL,
	TABLE_ID INT NOT NULL,
	COLUMN_NAME VARCHAR(100) NOT NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (TABLE_ID,WORD_ID,COLUMN_NAME)
);

CREATE TABLE SBI_GL_WLIST (
	CONTENT_ID INT NOT NULL,
	WORD_ID INT NOT NULL,
	WORD_ORDER INT NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (CONTENT_ID,WORD_ID)
);

CREATE TABLE SBI_GL_WORD (
	WORD_ID INT NOT NULL,
	WORD VARCHAR(100) NULL,
	DESCR VARCHAR(500) NULL,
	FORMULA VARCHAR(500) NULL,
	STATE INT NULL,
	CATEGORY INT NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (WORD_ID)
);

CREATE TABLE SBI_GL_WORD_ATTR (
	WORD_ID INT NOT NULL,
	ATTRIBUTE_ID INT NOT NULL,
	ATTR_VALUE VARCHAR(500) NULL,
	ATTR_ORDER INT NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (WORD_ID,ATTRIBUTE_ID)
);

CREATE TABLE SBI_I18N_MESSAGES (
	LANGUAGE_CD INT NOT NULL,
	LABEL VARCHAR(200) NOT NULL,
	MESSAGE TEXT NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NOT NULL,
	PRIMARY KEY (LANGUAGE_CD,LABEL,ORGANIZATION)
);

CREATE TABLE SBI_IMAGES (
	IMAGE_ID INT NOT NULL,
	NAME VARCHAR(100) NOT NULL,
	CONTENT VARBINARY(MAX) NOT NULL,
	CONTENT_ICO VARBINARY(MAX) NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (IMAGE_ID)
);

CREATE TABLE SBI_KPI_ALIAS (
	ID INT NOT NULL,
	NAME VARCHAR(40) NOT NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (ID)
);

CREATE TABLE SBI_KPI_EXECUTION (
	ID INT NOT NULL,
	NAME VARCHAR(40) NOT NULL,
	START_DATE DATETIME NULL,
	END_DATE DATETIME NULL,
	DELTA CHAR(1) NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (ID)
);

CREATE TABLE SBI_KPI_EXECUTION_FILTER (
	PLACEHOLDER_ID INT NOT NULL,
	EXECUTION_ID INT NOT NULL,
	KPI_ID INT NOT NULL,
	KPI_VERSION INT NOT NULL,
	TYPE_ID INT NULL,
	VALUE VARCHAR(40) NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (PLACEHOLDER_ID,EXECUTION_ID,KPI_ID,KPI_VERSION)
);

CREATE TABLE SBI_KPI_EXECUTION_KPI (
	KPI_ID INT NOT NULL,
	KPI_VERSION INT NOT NULL,
	EXECUTION_ID INT NOT NULL,
	PRIMARY KEY (KPI_ID,KPI_VERSION,EXECUTION_ID)
);

CREATE TABLE SBI_KPI_KPI (
	ID INT NOT NULL,
	VERSION INT NOT NULL,
	NAME VARCHAR(40) NOT NULL,
	DEFINITION VARCHAR(4000) NOT NULL,
	CARDINALITY VARCHAR(4000) NOT NULL,
	PLACEHOLDER VARCHAR(1024) NULL,
	CATEGORY_ID INT NULL,
	THRESHOLD_ID INT NOT NULL,
	ACTIVE CHAR(1) NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (ID,VERSION)
);

CREATE TABLE SBI_KPI_KPI_RULE_OUTPUT (
	KPI_ID INT NOT NULL,
	KPI_VERSION INT NOT NULL,
	RULE_OUTPUT_ID INT NOT NULL,
	PRIMARY KEY (KPI_ID,KPI_VERSION,RULE_OUTPUT_ID)
);

CREATE TABLE SBI_KPI_PLACEHOLDER (
	ID INT NOT NULL,
	NAME VARCHAR(40) NOT NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (ID)
);

CREATE TABLE SBI_KPI_RULE (
	ID INT NOT NULL,
	VERSION INT NOT NULL,
	NAME VARCHAR(40) NOT NULL,
	DEFINITION VARCHAR(4000) NOT NULL,
	DATASOURCE_ID INT NOT NULL,
	ACTIVE CHAR(1) NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (ID,VERSION)
);

CREATE TABLE SBI_KPI_RULE_OUTPUT (
	ID INT NOT NULL,
	RULE_ID INT NOT NULL,
	RULE_VERSION INT NOT NULL,
	TYPE_ID INT NOT NULL,
	ALIAS_ID INT NOT NULL,
	CATEGORY_ID INT NULL,
	HIERARCHY_ID INT NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (ID)
);

CREATE TABLE SBI_KPI_RULE_PLACEHOLDER (
	RULE_ID INT NOT NULL,
	RULE_VERSION INT NOT NULL,
	PLACEHOLDER_ID INT NOT NULL,
	PRIMARY KEY (RULE_ID,RULE_VERSION,PLACEHOLDER_ID)
);

CREATE TABLE SBI_KPI_SCORECARD (
	ID INT NOT NULL,
	PARENT_ID INT NULL,
	NAME VARCHAR(40) NOT NULL,
	CRITERION_ID INT NULL,
	OPTIONS VARCHAR(1000) NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (ID)
);

CREATE TABLE SBI_KPI_SCORECARD_KPI (
	KPI_ID INT NOT NULL,
	KPI_VERSION INT NOT NULL,
	SCORECARD_ID INT NOT NULL,
	PRIMARY KEY (KPI_ID,KPI_VERSION,SCORECARD_ID)
);

CREATE TABLE SBI_KPI_TARGET (
	TARGET_ID INT NOT NULL,
	NAME VARCHAR(40) NULL,
	CATEGORY_ID INT NULL,
	START_VALIDITY_DAY DATETIME NULL,
	END_VALIDITY_DAY DATETIME NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (TARGET_ID)
);

CREATE TABLE SBI_KPI_TARGET_VALUE (
	TARGET_ID INT NOT NULL,
	KPI_ID INT NOT NULL,
	KPI_VERSION INT NOT NULL,
	TARGET_VALUE FLOAT(53) NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (TARGET_ID,KPI_ID,KPI_VERSION)
);

CREATE TABLE SBI_KPI_THRESHOLD (
	ID INT NOT NULL,
	NAME VARCHAR(40) NOT NULL,
	DESCRIPTION VARCHAR(1024) NULL,
	TYPE_ID INT NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (ID)
);

CREATE TABLE SBI_KPI_THRESHOLD_VALUE (
	ID INT NOT NULL,
	THRESHOLD_ID INT NOT NULL,
	POSITION INT NULL,
	LABEL VARCHAR(40) NULL,
	MIN_VALUE FLOAT(53) NULL,
	INCLUDE_MIN CHAR(1) NULL,
	MAX_VALUE FLOAT(53) NULL,
	INCLUDE_MAX CHAR(1) NULL,
	COLOR VARCHAR(20) NULL,
	SEVERITY_ID INT NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (ID)
);

CREATE TABLE SBI_KPI_VALUE (
	ID INT NOT NULL,
	KPI_ID INT NOT NULL,
	KPI_VERSION INT NOT NULL,
	LOGICAL_KEY VARCHAR(4000),
	TIME_RUN DATETIME DEFAULT GETDATE(),
	COMPUTED_VALUE FLOAT(53) NOT NULL,
	MANUAL_VALUE FLOAT(53) NULL,
	MANUAL_NOTE VARCHAR(1000) NULL,
	THE_DAY VARCHAR(3) NOT NULL,
	THE_WEEK VARCHAR(3) NOT NULL,
	THE_MONTH VARCHAR(3) NOT NULL,
	THE_QUARTER VARCHAR(3) NOT NULL,
	THE_YEAR VARCHAR(4) NOT NULL,
	STATE CHAR(1) DEFAULT '0',
	PRIMARY KEY (ID)
);

CREATE TABLE SBI_KPI_VALUE_EXEC_LOG (
	ID INT NOT NULL,
	SCHEDULER_ID INT NOT NULL,
	TIME_RUN DATETIME NOT NULL,
	OUTPUT VARBINARY(MAX) NULL,
	ERROR_COUNT INT NOT NULL,
	SUCCESS_COUNT INT NOT NULL,
	TOTAL_COUNT INT NOT NULL,
	PRIMARY KEY (ID)
);

CREATE TABLE SBI_LOV (
	LOV_ID INT NOT NULL,
	DESCR VARCHAR(160) NULL,
	LABEL VARCHAR(20) NOT NULL,
	INPUT_TYPE_CD VARCHAR(20) NOT NULL,
	DEFAULT_VAL VARCHAR(40) NULL,
	LOV_PROVIDER TEXT NULL,
	INPUT_TYPE_ID INT NOT NULL,
	PROFILE_ATTR VARCHAR(20) NULL,
	NAME VARCHAR(40) NOT NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	DATASET_ID INT NULL,
	PRIMARY KEY (LOV_ID)
);

CREATE TABLE SBI_MENU (
	MENU_ID INT NOT NULL,
	NAME VARCHAR(50) NULL,
	DESCR VARCHAR(2000) NULL,
	PARENT_ID INT DEFAULT 0 NULL,
	BIOBJ_ID INT NULL,
	VIEW_ICONS BIT NULL,
	HIDE_TOOLBAR BIT NULL,
	HIDE_SLIDERS BIT NULL,
	STATIC_PAGE VARCHAR(45) NULL,
	BIOBJ_PARAMETERS TEXT NULL,
	SUBOBJ_NAME VARCHAR(50) NULL,
	SNAPSHOT_NAME VARCHAR(100) NULL,
	SNAPSHOT_HISTORY INT NULL,
	FUNCTIONALITY VARCHAR(50) NULL,
	INITIAL_PATH VARCHAR(400) NULL,
	EXT_APP_URL VARCHAR(1000) NULL,
	PROG INT DEFAULT 1 NOT NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (MENU_ID)
);

CREATE TABLE SBI_MENU_ROLE (
	MENU_ID INT NOT NULL,
	EXT_ROLE_ID INT NOT NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (MENU_ID,EXT_ROLE_ID)
);

CREATE TABLE SBI_META_BC (
	BC_ID INT NOT NULL,
	MODEL_ID INT NOT NULL,
	NAME VARCHAR(100) NOT NULL,
	UNIQUE_NAME VARCHAR(100) NULL,
	DELETED BIT DEFAULT 0 NOT NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (BC_ID)
);

CREATE TABLE SBI_META_BC_ATTRIBUTE (
	ATTRIBUTE_ID INT NOT NULL,
	BC_ID INT NULL,
	COLUMN_ID INT NULL,
	NAME VARCHAR(100) NOT NULL,
	TYPE VARCHAR(100) NULL,
	DELETED BIT DEFAULT 0 NOT NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (ATTRIBUTE_ID)
);

CREATE TABLE SBI_META_DATASET_REL (
	DS_TABLE_REL_ID INT NOT NULL,
	DATASET_ID INT NOT NULL,
	TABLE_ID INT NOT NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (DS_TABLE_REL_ID)
);

CREATE TABLE SBI_META_DOCUMENT_REL (
	DOC_TABLE_REL_ID INT NOT NULL,
	DOCUMENT_ID INT NOT NULL,
	TABLE_ID INT NOT NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (DOC_TABLE_REL_ID)
);

CREATE TABLE SBI_META_DS_BC (
	DS_ID INT NOT NULL,
	VERSION_NUM INT NOT NULL,
	BC_ID INT NOT NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NOT NULL,
	PRIMARY KEY (DS_ID,VERSION_NUM,ORGANIZATION,BC_ID)
);

CREATE TABLE SBI_META_JOB (
	JOB_ID INT NOT NULL,
	NAME VARCHAR(100) NOT NULL,
	DELETED BIT DEFAULT 0 NOT NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (JOB_ID)
);

CREATE TABLE SBI_META_JOB_SOURCE (
	JOB_ID INT NOT NULL,
	SOURCE_ID INT NOT NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (JOB_ID,SOURCE_ID)
);

CREATE TABLE SBI_META_JOB_TABLE (
	JOB_ID INT NOT NULL,
	TABLE_ID INT NOT NULL,
	ROLE VARCHAR(100) NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (JOB_ID,TABLE_ID)
);

CREATE TABLE SBI_META_MODELS (
	ID INT NOT NULL,
	NAME VARCHAR(100) NOT NULL,
	DESCR VARCHAR(500) NULL,
	MODEL_LOCKED BIT NULL,
	MODEL_LOCKER VARCHAR(100) NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	CATEGORY_ID INT NULL,
	DATA_SOURCE_ID INT NULL,
	PRIMARY KEY (ID)
);

CREATE TABLE SBI_META_MODELS_VERSIONS (
	ID INT NOT NULL,
	MODEL_ID INT NOT NULL,
	CONTENT VARBINARY(MAX) NULL,
	NAME VARCHAR(100) NULL,
	FILE_MODEL VARBINARY(MAX) NULL,
	PROG INT NULL,
	CREATION_DATE DATETIME NULL,
	CREATION_USER VARCHAR(50) NOT NULL,
	ACTIVE BIT NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NULL DEFAULT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (ID)
);

CREATE TABLE SBI_META_OBJ_DS (
	DS_ID INT NOT NULL,
	VERSION_NUM INT NOT NULL,
	OBJ_ID INT NOT NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NOT NULL,
	PRIMARY KEY (DS_ID,VERSION_NUM,ORGANIZATION,OBJ_ID)
);

CREATE TABLE SBI_META_SOURCE (
	SOURCE_ID INT NOT NULL,
	NAME VARCHAR(100) NOT NULL,
	TYPE VARCHAR(100) NOT NULL,
	URL VARCHAR(100) NULL,
	LOCATION VARCHAR(100) NULL,
	SOURCE_SCHEMA VARCHAR(100) NULL,
	SOURCE_CATALOGUE VARCHAR(100) NULL,
	ROLE VARCHAR(100) NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (SOURCE_ID)
);

CREATE TABLE SBI_META_TABLE (
	TABLE_ID INT NOT NULL,
	SOURCE_ID INT NOT NULL,
	NAME VARCHAR(100) NOT NULL,
	DELETED BIT DEFAULT 0 NOT NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (TABLE_ID)
);

CREATE TABLE SBI_META_TABLE_BC (
	TABLE_ID INT NOT NULL,
	BC_ID INT NOT NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (TABLE_ID,BC_ID)
);

CREATE TABLE SBI_META_TABLE_COLUMN (
	COLUMN_ID INT NOT NULL,
	TABLE_ID INT NOT NULL,
	NAME VARCHAR(100) NOT NULL,
	TYPE VARCHAR(100) NOT NULL,
	DELETED BIT DEFAULT 0 NOT NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (COLUMN_ID)
);

CREATE TABLE SBI_OBJ_DATA_SET (
	BIOBJ_DS_ID INT NOT NULL,
	BIOBJ_ID INT NOT NULL,
	DS_ID INT NOT NULL,
	IS_DETAIL BIT DEFAULT 0 NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (BIOBJ_DS_ID)
);

CREATE TABLE SBI_OBJ_FUNC (
	BIOBJ_ID INT NOT NULL,
	FUNCT_ID INT NOT NULL,
	PROG INT NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (BIOBJ_ID,FUNCT_ID)
);

CREATE TABLE SBI_OBJ_FUNC_ORGANIZER (
	BIOBJ_ID INT NOT NULL,
	FUNCT_ID INT NOT NULL,
	PROG INT NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (BIOBJ_ID,FUNCT_ID)
);

CREATE TABLE SBI_OBJ_METACONTENTS (
	OBJ_METACONTENT_ID INT NOT NULL,
	OBJMETA_ID INT NOT NULL,
	BIOBJ_ID INT NOT NULL,
	SUBOBJ_ID INT NULL,
	BIN_ID INT NULL,
	CREATION_DATE DATETIME NOT NULL DEFAULT getdate(),
	LAST_CHANGE_DATE DATETIME NOT NULL DEFAULT getdate(),
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NULL DEFAULT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	ADDITIONAL_INFO VARCHAR(255) NULL,
	PRIMARY KEY (OBJ_METACONTENT_ID)
);

CREATE TABLE SBI_OBJ_METADATA (
	OBJ_META_ID INT NOT NULL,
	LABEL VARCHAR(20) NOT NULL,
	NAME VARCHAR(40) NOT NULL,
	DESCR VARCHAR(100) NULL,
	DATA_TYPE_ID INT NOT NULL,
	CREATION_DATE DATETIME NOT NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NULL DEFAULT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (OBJ_META_ID)
);

CREATE TABLE SBI_OBJ_PAR (
	OBJ_PAR_ID INT NOT NULL,
	PAR_ID INT NOT NULL,
	BIOBJ_ID INT NOT NULL,
	LABEL VARCHAR(40) NOT NULL,
	REQ_FL SMALLINT NULL,
	MOD_FL SMALLINT NULL,
	VIEW_FL SMALLINT NULL,
	MULT_FL SMALLINT NULL,
	PROG INT NOT NULL,
	PARURL_NM VARCHAR(20) NULL,
	PRIORITY INT NULL,
	COL_SPAN INT DEFAULT 1 NULL,
	THICK_PERC INT DEFAULT 0 NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (OBJ_PAR_ID)
);

CREATE TABLE SBI_OBJ_PARUSE (
	OBJ_PAR_ID INT NOT NULL,
	USE_ID INT NOT NULL,
	OBJ_PAR_FATHER_ID INT NOT NULL,
	FILTER_OPERATION VARCHAR(20) NOT NULL,
	PROG INT NOT NULL,
	FILTER_COLUMN VARCHAR(30) NOT NULL,
	PRE_CONDITION VARCHAR(10) NULL,
	POST_CONDITION VARCHAR(10) NULL,
	LOGIC_OPERATOR VARCHAR(10) NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (OBJ_PAR_ID,USE_ID,OBJ_PAR_FATHER_ID,FILTER_OPERATION)
);

CREATE TABLE SBI_OBJ_PARVIEW (
	OBJ_PAR_ID INT NOT NULL,
	OBJ_PAR_FATHER_ID INT NOT NULL,
	OPERATION VARCHAR(20) NOT NULL,
	COMPARE_VALUE VARCHAR(200) NOT NULL,
	VIEW_LABEL VARCHAR(50) NULL,
	PROG INT NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (OBJ_PAR_ID,OBJ_PAR_FATHER_ID,OPERATION,COMPARE_VALUE)
);

CREATE TABLE SBI_OBJ_STATE (
	BIOBJ_ID INT NOT NULL,
	STATE_ID INT NOT NULL,
	END_DT DATE NULL,
	START_DT DATE NOT NULL,
	NOTE VARCHAR(300) NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (BIOBJ_ID,STATE_ID,START_DT)
);

CREATE TABLE SBI_OBJECT_NOTES (
	OBJ_NOTE_ID INT NOT NULL,
	BIOBJ_ID INT NULL,
	BIN_ID INT NULL,
	EXEC_REQ VARCHAR(500) NULL,
	OWNER VARCHAR(50) NULL,
	ISPUBLIC BIT NULL,
	CREATION_DATE DATETIME NOT NULL DEFAULT getdate(),
	LAST_CHANGE_DATE DATETIME NOT NULL DEFAULT getdate(),
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NULL DEFAULT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (OBJ_NOTE_ID)
);

CREATE TABLE SBI_OBJECT_TEMPLATES (
	OBJ_TEMP_ID INT NOT NULL,
	BIOBJ_ID INT NULL,
	BIN_ID INT NULL,
	NAME VARCHAR(50) NULL,
	PROG INT NULL,
	DIMENSION VARCHAR(20) NULL,
	CREATION_DATE DATE NULL,
	CREATION_USER VARCHAR(45) NOT NULL,
	ACTIVE BIT NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (OBJ_TEMP_ID)
);

CREATE TABLE SBI_OBJECTS (
	BIOBJ_ID INT NOT NULL,
	ENGINE_ID INT NOT NULL,
	DESCR VARCHAR(400) NULL,
	LABEL VARCHAR(100) NOT NULL,
	ENCRYPT SMALLINT NULL,
	PATH VARCHAR(400) NULL,
	REL_NAME VARCHAR(400) NULL,
	STATE_ID INT NOT NULL,
	STATE_CD VARCHAR(20) NOT NULL,
	BIOBJ_TYPE_CD VARCHAR(20) NOT NULL,
	BIOBJ_TYPE_ID INT NOT NULL,
	SCHED_FL SMALLINT NULL,
	EXEC_MODE_ID INT NULL,
	STATE_CONS_ID INT NULL,
	EXEC_MODE_CD VARCHAR(20) NULL,
	STATE_CONS_CD VARCHAR(20) NULL,
	NAME VARCHAR(200) NOT NULL,
	VISIBLE SMALLINT NOT NULL,
	UUID VARCHAR(40) NOT NULL,
	DATA_SOURCE_ID INT NULL,
	CREATION_DATE DATETIME NOT NULL,
	CREATION_USER VARCHAR(45) NOT NULL,
	REFRESH_SECONDS INT NULL,
	PROF_VISIBILITY VARCHAR(400) NULL,
	PREVIEW_FILE VARCHAR(100) NULL,
	PARAMETERS_REGION VARCHAR(20) NULL,
	LOCKED_BY_USER VARCHAR(100) NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NULL DEFAULT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (BIOBJ_ID)
);

CREATE TABLE SBI_OBJECTS_RATING (
	USER_ID VARCHAR(127) NOT NULL,
	OBJ_ID INT NOT NULL,
	RATING INT NOT NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (USER_ID,OBJ_ID)
);

CREATE TABLE SBI_ORGANIZATION_DATASOURCE (
	DATASOURCE_ID INT NOT NULL,
	ORGANIZATION_ID INT NOT NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (DATASOURCE_ID,ORGANIZATION_ID)
);

CREATE TABLE SBI_ORGANIZATION_PRODUCT_TYPE (
	PRODUCT_TYPE_ID INT NOT NULL,
	ORGANIZATION_ID INT NOT NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (PRODUCT_TYPE_ID,ORGANIZATION_ID)
);

CREATE TABLE SBI_ORGANIZATIONS (
	ID INT NOT NULL,
	NAME VARCHAR(200) NULL,
	THEME VARCHAR(100) NULL DEFAULT 'SPAGOBI.THEMES.THEME.default',
	PRIMARY KEY (ID)
);

CREATE TABLE SBI_OUTPUT_PARAMETER (
	ID INT NOT NULL,
	BIOBJ_ID INT NOT NULL,
	PAR_TYPE_ID INT NOT NULL,
	LABEL VARCHAR(40) NOT NULL,
	FORMAT_CODE VARCHAR(20) NULL,
	FORMAT_VALUE VARCHAR(20) NULL,
	IS_USER_DEFINED BIT DEFAULT 0,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (ID)
);

CREATE TABLE SBI_PARAMETERS (
	PAR_ID INT NOT NULL,
	DESCR VARCHAR(160) NULL,
	LENGTH SMALLINT NOT NULL,
	LABEL VARCHAR(20) NOT NULL,
	PAR_TYPE_CD VARCHAR(20) NOT NULL,
	MASK VARCHAR(20) NULL,
	PAR_TYPE_ID INT NOT NULL,
	NAME VARCHAR(40) NOT NULL,
	FUNCTIONAL_FLAG SMALLINT DEFAULT 1 NOT NULL,
	TEMPORAL_FLAG SMALLINT DEFAULT 0 NOT NULL,
	VALUE_SELECTION VARCHAR(20) NULL,
	SELECTED_LAYER VARCHAR(100) NULL,
	SELECTED_LAYER_PROP VARCHAR(40) NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (PAR_ID)
);

CREATE TABLE SBI_PARUSE (
	USE_ID INT NOT NULL,
	LOV_ID INT NULL,
	DEFAULT_LOV_ID INT NULL,
	DEFAULT_FORMULA VARCHAR(4000) NULL,
	LABEL VARCHAR(20) NOT NULL,
	DESCR VARCHAR(160) NULL,
	PAR_ID INT NOT NULL,
	NAME VARCHAR(40) NOT NULL,
	MAN_IN INT NOT NULL,
	MAXIMIZER_ENABLED BIT DEFAULT 0 NULL,
	SELECTION_TYPE VARCHAR(20) DEFAULT 'LIST' NULL,
	MULTIVALUE_FLAG INT DEFAULT 0 NULL,
	VALUE_SELECTION VARCHAR(20) NULL,
	SELECTED_LAYER VARCHAR(100) NULL,
	SELECTED_LAYER_PROP VARCHAR(40) NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	OPTIONS VARCHAR(4000) NULL,
	PRIMARY KEY (USE_ID)
);

CREATE TABLE SBI_PARUSE_CK (
	CHECK_ID INT NOT NULL,
	USE_ID INT NOT NULL,
	PROG INT NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (USE_ID,CHECK_ID)
);

CREATE TABLE SBI_PARUSE_DET (
	EXT_ROLE_ID INT NOT NULL,
	PROG INT NULL,
	USE_ID INT NOT NULL,
	HIDDEN_FL SMALLINT NULL,
	DEFAULT_VAL VARCHAR(40) NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (USE_ID,EXT_ROLE_ID)
);

CREATE TABLE SBI_PRODUCT_TYPE (
	PRODUCT_TYPE_ID INT NOT NULL,
	LABEL VARCHAR(40) NOT NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (PRODUCT_TYPE_ID)
);

CREATE TABLE SBI_PRODUCT_TYPE_ENGINE (
	PRODUCT_TYPE_ID INT NOT NULL,
	ENGINE_ID INT NOT NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (PRODUCT_TYPE_ID,ENGINE_ID)
);

CREATE TABLE SBI_PROGRESS_THREAD (
	PROGRESS_THREAD_ID INT NOT NULL,
	USER_ID VARCHAR(100) NOT NULL,
	PARTIAL INT NULL,
	TOTAL INT NULL,
	FUNCTION_CD VARCHAR(200) NULL,
	STATUS VARCHAR(4000) NULL,
	RANDOM_KEY VARCHAR(4000) NULL,
	TYPE VARCHAR(200) NULL,
	PRIMARY KEY (PROGRESS_THREAD_ID)
);

CREATE TABLE SBI_REMEMBER_ME (
	ID INT NOT NULL,
	NAME VARCHAR(50) NOT NULL,
	DESCRIPTION TEXT NULL,
	USERNAME VARCHAR(40) NOT NULL,
	BIOBJ_ID INT NOT NULL,
	SUBOBJ_ID INT NULL,
	PARAMETERS TEXT NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (ID)
);

CREATE TABLE SBI_ROLE_TYPE_USER_FUNC (
	ROLE_TYPE_ID INT NOT NULL,
	USER_FUNCT_ID INT NOT NULL,
	PRIMARY KEY (ROLE_TYPE_ID,USER_FUNCT_ID)
);

CREATE TABLE SBI_ROLES_LAYERS (
	ID_LAYER INT NOT NULL,
	ID_ROLE INT NOT NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (ID_LAYER,ID_ROLE)
);

CREATE TABLE SBI_SNAPSHOTS (
	SNAP_ID INT NOT NULL,
	BIOBJ_ID INT NULL,
	BIN_ID INT NULL,
	NAME VARCHAR(100) NULL,
	DESCRIPTION VARCHAR(1000) NULL,
	CREATION_DATE DATETIME NOT NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NULL DEFAULT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	CONTENT_TYPE VARCHAR(300) NULL,
	SCHEDULATION	VARCHAR(100),
	SCHEDULER	VARCHAR(100),
	SCHEDULATION_START	INT,
	SEQUENCE INT,
	PRIMARY KEY (SNAP_ID)
);

CREATE TABLE SBI_SUBOBJECTS (
	SUBOBJ_ID INT NOT NULL,
	BIOBJ_ID INT NULL,
	BIN_ID INT NULL,
	NAME VARCHAR(50) NOT NULL,
	DESCRIPTION VARCHAR(100) NULL,
	OWNER VARCHAR(50) NULL,
	ISPUBLIC BIT NULL,
	CREATION_DATE DATETIME NOT NULL DEFAULT getdate(),
	LAST_CHANGE_DATE DATETIME NOT NULL DEFAULT getdate(),
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NULL DEFAULT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (SUBOBJ_ID)
);

CREATE TABLE SBI_SUBREPORTS (
	MASTER_RPT_ID INT NOT NULL,
	SUB_RPT_ID INT NOT NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (MASTER_RPT_ID,SUB_RPT_ID)
);

CREATE TABLE SBI_TIMESPAN (
	ID INT NOT NULL,
	NAME VARCHAR(45) NOT NULL,
	TYPE VARCHAR(45) NOT NULL,
	CATEGORY VARCHAR(45) NULL,
	STATIC_FILTER BIT DEFAULT 0 NULL,
	DEFINITION VARCHAR(4000) NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (ID)
);

CREATE TABLE SBI_TRIGGER_PAUSED (
	ID INT NOT NULL,
	TRIGGER_NAME VARCHAR(80) NOT NULL,
	TRIGGER_GROUP VARCHAR(80) NOT NULL,
	JOB_NAME VARCHAR(80) NOT NULL,
	JOB_GROUP VARCHAR(80) NOT NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (ID)
);

CREATE TABLE SBI_UDP (
	UDP_ID INT NOT NULL,
	TYPE_ID INT NOT NULL,
	FAMILY_ID INT NOT NULL,
	LABEL VARCHAR(20) NOT NULL,
	NAME VARCHAR(40) NOT NULL,
	DESCRIPTION VARCHAR(1000) NULL,
	IS_MULTIVALUE BIT DEFAULT 0 NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (UDP_ID)
);

CREATE TABLE SBI_UDP_VALUE (
	UDP_VALUE_ID INT NOT NULL,
	UDP_ID INT NOT NULL,
	VALUE VARCHAR(1000) NULL,
	PROG INT NULL,
	LABEL VARCHAR(20) NULL,
	NAME VARCHAR(40) NULL,
	FAMILY VARCHAR(40) NULL,
	BEGIN_TS DATETIME NOT NULL,
	END_TS DATETIME NULL,
	REFERENCE_ID INT NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NULL DEFAULT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (UDP_VALUE_ID)
);

CREATE TABLE SBI_USER (
	USER_ID CHAR(100) NOT NULL,
	PASSWORD VARCHAR(150) NULL,
	FULL_NAME VARCHAR(255) NULL,
	ID INT NOT NULL,
	DT_PWD_BEGIN DATE NULL,
	DT_PWD_END DATE NULL,
	FLG_PWD_BLOCKED BIT NULL,
	DT_LAST_ACCESS DATE NULL,
	IS_SUPERADMIN BIT DEFAULT 0 NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (ID)
);

CREATE TABLE SBI_USER_ATTRIBUTES (
	ID INT NOT NULL,
	ATTRIBUTE_ID INT NOT NULL,
	ATTRIBUTE_VALUE VARCHAR(500) NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (ID,ATTRIBUTE_ID)
);

CREATE TABLE SBI_USER_FUNC (
	USER_FUNCT_ID INT NOT NULL,
	NAME VARCHAR(50) NULL,
	DESCRIPTION VARCHAR(100) NULL,
	PRODUCT_TYPE_ID INT NOT NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (USER_FUNCT_ID)
);

CREATE TABLE SBI_VIEWPOINTS (
	VP_ID INT NOT NULL,
	BIOBJ_ID INT NOT NULL,
	VP_NAME VARCHAR(40) NOT NULL,
	VP_OWNER VARCHAR(40) NULL,
	VP_DESC VARCHAR(160) NULL,
	VP_SCOPE VARCHAR(20) NOT NULL,
	VP_VALUE_PARAMS TEXT NULL,
	VP_CREATION_DATE DATETIME NOT NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NULL DEFAULT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (VP_ID)
);

CREATE TABLE SBI_WS_EVENT (
	ID INT NOT NULL,
	EVENT_NAME VARCHAR(80) NOT NULL,
	IP_COME_FROM VARCHAR(15) NULL,
	INCOMING_DATE DATE NULL,
	TAKE_CHARGE_DATE DATE NULL,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NOT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	META_VERSION VARCHAR(100) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	PRIMARY KEY (ID)
);


CREATE TABLE SBI_WHATIF_WORKFLOW(
	ID INT,
    MODEL_ID INT,
    USER_ID INT,
    SEQUENCE INT,
    STATE VARCHAR(20),
    NOTES VARCHAR(100),
    INFO VARCHAR(100),
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NULL DEFAULT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	ORGANIZATION VARCHAR(20) NULL,
    PRIMARY KEY (ID)
);

CREATE TABLE  SBI_DOSSIER_ACTIVITY(
		ID 					INT NOT NULL,
		PROGRESS 			INT NOT NULL,
		PPT					VARBINARY(MAX) NOT NULL,
	    DOCUMENT_ID 		INT,
	    ACTIVITY 			VARCHAR(45) NOT NULL,
	    PARAMS 				VARCHAR(4000),
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) NULL,
	USER_DE VARCHAR(100) NULL,
	TIME_IN DATETIME NULL DEFAULT NULL,
	TIME_UP DATETIME NULL,
	TIME_DE DATETIME NULL,
	SBI_VERSION_IN VARCHAR(10) NULL,
	SBI_VERSION_UP VARCHAR(10) NULL,
	SBI_VERSION_DE VARCHAR(10) NULL,
	ORGANIZATION VARCHAR(20) NULL,
	    PRIMARY KEY (ID)
);


ALTER TABLE SBI_GEO_LAYERS ADD CONSTRAINT XAK1SBI_GEO_LAYERS UNIQUE (
	LABEL,
	ORGANIZATION
);

ALTER TABLE SBI_FEDERATION_DEFINITION ADD CONSTRAINT XAK1SBI_FEDERATION_DEFINITION_1 UNIQUE (
	LABEL,
	ORGANIZATION
);

ALTER TABLE SBI_FEDERATION_DEFINITION ADD CONSTRAINT XAK1SBI_FEDERATION_DEFINITION_2 UNIQUE (
	NAME,
	ORGANIZATION
);

ALTER TABLE SBI_IMAGES ADD CONSTRAINT XAK1SBI_IMAGES UNIQUE (
	NAME
);

ALTER TABLE SBI_CATALOG_FUNCTION ADD CONSTRAINT XAK1SBI_CATALOG_FUNCTION UNIQUE (
	LABEL,
	ORGANIZATION
);

ALTER TABLE SBI_ARTIFACTS ADD CONSTRAINT XAK1SBI_ARTIFACTS UNIQUE (
	NAME,
	TYPE,
	ORGANIZATION
);

ALTER TABLE SBI_CACHE_ITEM ADD CONSTRAINT XAK1SBI_CACHE_ITEM UNIQUE (
	TABLE_NAME
);

ALTER TABLE SBI_CHECKS ADD CONSTRAINT XAK1SBI_CHECKS UNIQUE (
	LABEL,
	ORGANIZATION
);

ALTER TABLE SBI_CONFIG ADD CONSTRAINT XAK1SBI_CONFIG UNIQUE (
	LABEL
);

ALTER TABLE SBI_DATA_SET ADD CONSTRAINT XAK1SBI_DATA_SET UNIQUE (
	LABEL,
	VERSION_NUM,
	ORGANIZATION
);

ALTER TABLE SBI_DATA_SOURCE ADD CONSTRAINT XAK1SBI_DATA_SOURCE UNIQUE (
	LABEL,
	ORGANIZATION
);

ALTER TABLE SBI_DIST_LIST_USER ADD CONSTRAINT XAK1SBI_DL_USER UNIQUE (
	LIST_ID,
	USER_ID
);

ALTER TABLE SBI_DOMAINS ADD CONSTRAINT XAK1SBI_DOMAINS UNIQUE (
	VALUE_CD,
	DOMAIN_CD
);

ALTER TABLE SBI_ENGINES ADD CONSTRAINT XAK1SBI_ENGINES UNIQUE (
	LABEL,
	ORGANIZATION
);

ALTER TABLE SBI_EXPORTERS ADD CONSTRAINT XAK1SBI_EXPORTERS UNIQUE (
	ENGINE_ID,
	DOMAIN_ID
);

ALTER TABLE SBI_EXT_ROLES ADD CONSTRAINT XAK1SBI_EXT_ROLES UNIQUE (
	NAME,
	ORGANIZATION
);

ALTER TABLE SBI_FUNCTIONS ADD CONSTRAINT XAK1SBI_FUNCTIONS UNIQUE (
	CODE,
	ORGANIZATION
);

ALTER TABLE SBI_FUNCTIONS_ORGANIZER ADD CONSTRAINT XAK1SBI_FUNCTIONS_ORGANIZER UNIQUE (
	CODE,
	USER_IN
);

ALTER TABLE SBI_GEO_FEATURES ADD CONSTRAINT XAK1SBI_GEO_FEATURES UNIQUE (
	NAME,
	ORGANIZATION
);

ALTER TABLE SBI_GEO_MAPS ADD CONSTRAINT XAK1SBI_GEO_MAPS UNIQUE (
	NAME,
	ORGANIZATION
);

ALTER TABLE SBI_LOV ADD CONSTRAINT XAK1SBI_LOV UNIQUE (
	LABEL,
	ORGANIZATION
);

ALTER TABLE SBI_META_MODELS ADD CONSTRAINT XAK1SBI_META_MODELS UNIQUE (
	NAME,
	ORGANIZATION
);

ALTER TABLE SBI_OBJECTS ADD CONSTRAINT XAK1SBI_OBJECTS UNIQUE (
	LABEL,
	ORGANIZATION
);

ALTER TABLE SBI_OBJ_DATA_SET ADD CONSTRAINT XAK1SBI_OBJ_DATA_SET UNIQUE (
	BIOBJ_ID,
	DS_ID,
	ORGANIZATION
);

ALTER TABLE SBI_OBJ_METACONTENTS ADD CONSTRAINT XAK1SBI_OBJ_METACONTENTS UNIQUE (
	OBJMETA_ID,
	BIOBJ_ID,
	SUBOBJ_ID
);

ALTER TABLE SBI_OBJ_METADATA ADD CONSTRAINT XAK1SBI_OBJ_METADATA UNIQUE (
	LABEL,
	ORGANIZATION
);

ALTER TABLE SBI_ORGANIZATIONS ADD CONSTRAINT XAK1SBI_ORGANIZATIONS UNIQUE (
	NAME
);

ALTER TABLE SBI_PARAMETERS ADD CONSTRAINT XAK1SBI_PARAMETERS UNIQUE (
	LABEL,
	ORGANIZATION
);

ALTER TABLE SBI_PARUSE ADD CONSTRAINT XAK1SBI_PARUSE UNIQUE (
	PAR_ID,
	LABEL
);

ALTER TABLE SBI_PRODUCT_TYPE ADD CONSTRAINT XAK1SBI_PRODUCT_TYPE UNIQUE (
	LABEL,
	ORGANIZATION
);

ALTER TABLE SBI_DIST_LIST ADD CONSTRAINT XAK1SBI_SBI_DIST_LIST UNIQUE (
	NAME,
	ORGANIZATION
);

ALTER TABLE SBI_TRIGGER_PAUSED ADD CONSTRAINT XAK1SBI_TRIGGER_PAUSED UNIQUE (
	TRIGGER_NAME,
	TRIGGER_GROUP,
	JOB_NAME,
	JOB_GROUP
);

ALTER TABLE SBI_UDP ADD CONSTRAINT XAK1SBI_UDP UNIQUE (
	LABEL,
	ORGANIZATION
);

ALTER TABLE SBI_ATTRIBUTE ADD CONSTRAINT XAK1SBI_USER_1 UNIQUE (
	ATTRIBUTE_NAME,
	ORGANIZATION
);

ALTER TABLE SBI_USER ADD CONSTRAINT XAK1SBI_USER_2 UNIQUE (
	USER_ID
);

ALTER TABLE SBI_KPI_TARGET ADD CONSTRAINT XAK1SBI_KPI_TARGET UNIQUE (
	NAME,
	ORGANIZATION
);

ALTER TABLE SBI_AUTHORIZATIONS ADD CONSTRAINT FK2_PRODUCT_TYPE FOREIGN KEY (PRODUCT_TYPE_ID) REFERENCES SBI_PRODUCT_TYPE (PRODUCT_TYPE_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_GL_CONTENTS ADD CONSTRAINT FK_01_GL_CONTENTS FOREIGN KEY (GLOSSARY_ID) REFERENCES SBI_GL_GLOSSARY (GLOSSARY_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_GL_REFERENCES ADD CONSTRAINT FK_01_GL_REFERENCES FOREIGN KEY (WORD_ID) REFERENCES SBI_GL_WORD (WORD_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_GL_WLIST ADD CONSTRAINT FK_01_GL_WLIST FOREIGN KEY (WORD_ID) REFERENCES SBI_GL_WORD (WORD_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_GL_WORD_ATTR ADD CONSTRAINT FK_01_GL_WORD_ATTR FOREIGN KEY (WORD_ID) REFERENCES SBI_GL_WORD (WORD_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_ALERT ADD CONSTRAINT FK_01_SBI_ALERT FOREIGN KEY (LISTENER_ID) REFERENCES SBI_ALERT_LISTENER (ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_ALERT_LOG ADD CONSTRAINT FK_01_SBI_ALERT_LOG FOREIGN KEY (LISTENER_ID) REFERENCES SBI_ALERT_LISTENER (ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_GL_BNESS_CLS_WLIST ADD CONSTRAINT FK_01_SBI_GL_BNESS_CLS_WLIST FOREIGN KEY (BC_ID) REFERENCES SBI_META_BC (BC_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_GL_DOCWLIST ADD CONSTRAINT FK_01_SBI_GL_DOCWLIST FOREIGN KEY (WORD_ID) REFERENCES SBI_GL_WORD (WORD_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_GL_TABLE_WLIST ADD CONSTRAINT FK_01_SBI_GL_TABLE_WLIST FOREIGN KEY (TABLE_ID) REFERENCES SBI_META_TABLE (TABLE_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_GL_WORD ADD CONSTRAINT FK_01_SBI_GL_WORD FOREIGN KEY (CATEGORY) REFERENCES SBI_DOMAINS (VALUE_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_KPI_EXECUTION_FILTER ADD CONSTRAINT FK_01_SBI_KPI_EXECUTION_FILTER FOREIGN KEY (EXECUTION_ID) REFERENCES SBI_KPI_EXECUTION (ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_KPI_KPI ADD CONSTRAINT FK_01_SBI_KPI_KPI FOREIGN KEY (CATEGORY_ID) REFERENCES SBI_DOMAINS (VALUE_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_KPI_KPI_RULE_OUTPUT ADD CONSTRAINT FK_01_SBI_KPI_KPI_RULE_OUTPUT FOREIGN KEY (KPI_ID,KPI_VERSION) REFERENCES SBI_KPI_KPI (ID,VERSION) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_KPI_RULE ADD CONSTRAINT FK_01_SBI_KPI_RULE FOREIGN KEY (DATASOURCE_ID) REFERENCES SBI_DATA_SOURCE (DS_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_KPI_RULE_OUTPUT ADD CONSTRAINT FK_01_SBI_KPI_RULE_OUTPUT FOREIGN KEY (TYPE_ID) REFERENCES SBI_DOMAINS (VALUE_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_KPI_RULE_PLACEHOLDER ADD CONSTRAINT FK_01_SBI_KPI_RULE_PLACEHOLDER FOREIGN KEY (RULE_ID,RULE_VERSION) REFERENCES SBI_KPI_RULE (ID,VERSION) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_KPI_TARGET_VALUE ADD CONSTRAINT FK_01_SBI_KPI_TARGET_VALUE FOREIGN KEY (TARGET_ID) REFERENCES SBI_KPI_TARGET (TARGET_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_KPI_THRESHOLD ADD CONSTRAINT FK_01_SBI_KPI_THRESHOLD FOREIGN KEY (TYPE_ID) REFERENCES SBI_DOMAINS (VALUE_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_KPI_THRESHOLD_VALUE ADD CONSTRAINT FK_01_SBI_KPI_THRESHOLD_VALUE FOREIGN KEY (SEVERITY_ID) REFERENCES SBI_DOMAINS (VALUE_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_GL_CONTENTS ADD CONSTRAINT FK_02_GL_CONTENTS FOREIGN KEY (PARENT_ID) REFERENCES SBI_GL_CONTENTS (CONTENT_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_GL_REFERENCES ADD CONSTRAINT FK_02_GL_REFERENCES FOREIGN KEY (REF_WORD_ID) REFERENCES SBI_GL_WORD (WORD_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_GL_WLIST ADD CONSTRAINT FK_02_GL_WLIST FOREIGN KEY (CONTENT_ID) REFERENCES SBI_GL_CONTENTS (CONTENT_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_GL_WORD_ATTR ADD CONSTRAINT FK_02_GL_WORD_ATTR FOREIGN KEY (ATTRIBUTE_ID) REFERENCES SBI_GL_ATTRIBUTES (ATTRIBUTE_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_ALERT_LOG ADD CONSTRAINT FK_02_SBI_ALERT_LOG FOREIGN KEY (ACTION_ID) REFERENCES SBI_ALERT_ACTION (ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_GL_BNESS_CLS_WLIST ADD CONSTRAINT FK_02_SBI_GL_BNESS_CLS_WLIST FOREIGN KEY (WORD_ID) REFERENCES SBI_GL_WORD (WORD_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_GL_DATASETWLIST ADD CONSTRAINT FK_02_SBI_GL_DATASETWLIST FOREIGN KEY (WORD_ID) REFERENCES SBI_GL_WORD (WORD_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_GL_DOCWLIST ADD CONSTRAINT FK_02_SBI_GL_DOCWLIST FOREIGN KEY (BIOBJ_ID) REFERENCES SBI_OBJECTS (BIOBJ_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_GL_TABLE_WLIST ADD CONSTRAINT FK_02_SBI_GL_TABLE_WLIST FOREIGN KEY (WORD_ID) REFERENCES SBI_GL_WORD (WORD_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_GL_WORD ADD CONSTRAINT FK_02_SBI_GL_WORD FOREIGN KEY (STATE) REFERENCES SBI_DOMAINS (VALUE_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_KPI_EXECUTION_FILTER ADD CONSTRAINT FK_02_SBI_KPI_EXECUTION_FILTER FOREIGN KEY (TYPE_ID) REFERENCES SBI_DOMAINS (VALUE_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_KPI_KPI_RULE_OUTPUT ADD CONSTRAINT FK_02_SBI_KPI_KPI_RULE_OUTPUT FOREIGN KEY (RULE_OUTPUT_ID) REFERENCES SBI_KPI_RULE_OUTPUT (ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_KPI_RULE_OUTPUT ADD CONSTRAINT FK_02_SBI_KPI_RULE_OUTPUT FOREIGN KEY (RULE_ID, RULE_VERSION) REFERENCES SBI_KPI_RULE (ID, VERSION) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_KPI_RULE_PLACEHOLDER ADD CONSTRAINT FK_02_SBI_KPI_RULE_PLACEHOLDER FOREIGN KEY (PLACEHOLDER_ID) REFERENCES SBI_KPI_PLACEHOLDER (ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_KPI_SCORECARD ADD CONSTRAINT FK_02_SBI_KPI_SCORECARD FOREIGN KEY (CRITERION_ID) REFERENCES SBI_DOMAINS (VALUE_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_KPI_TARGET_VALUE ADD CONSTRAINT FK_02_SBI_KPI_TARGET_VALUE FOREIGN KEY (KPI_ID, KPI_VERSION) REFERENCES SBI_KPI_KPI (ID, VERSION) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_KPI_THRESHOLD_VALUE ADD CONSTRAINT FK_02_SBI_KPI_THRESHOLD_VALUE FOREIGN KEY (THRESHOLD_ID) REFERENCES SBI_KPI_THRESHOLD (ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_KPI_EXECUTION_FILTER ADD CONSTRAINT FK_03_SBI_KPI_EXECUTION_FILTER FOREIGN KEY (PLACEHOLDER_ID) REFERENCES SBI_KPI_PLACEHOLDER (ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_KPI_RULE_OUTPUT ADD CONSTRAINT FK_03_SBI_KPI_RULE_OUTPUT FOREIGN KEY (ALIAS_ID) REFERENCES SBI_KPI_ALIAS (ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_KPI_TARGET ADD CONSTRAINT FK_03_SBI_KPI_TARGET FOREIGN KEY (CATEGORY_ID) REFERENCES SBI_DOMAINS (VALUE_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_KPI_RULE_OUTPUT ADD CONSTRAINT FK_04_SBI_KPI_RULE_OUTPUT FOREIGN KEY (CATEGORY_ID) REFERENCES SBI_DOMAINS (VALUE_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_AUTHORIZATIONS_ROLES ADD CONSTRAINT FK_AUTHORIZATION_1 FOREIGN KEY (AUTHORIZATION_ID) REFERENCES SBI_AUTHORIZATIONS (ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_COMMUNITY_USERS ADD CONSTRAINT FK_COMMUNITY FOREIGN KEY (COMMUNITY_ID) REFERENCES SBI_COMMUNITY (COMMUNITY_ID ) ON UPDATE NO ACTION ON DELETE CASCADE;

ALTER TABLE SBI_ORGANIZATION_DATASOURCE ADD CONSTRAINT FK_DATASOURCE_2 FOREIGN KEY (DATASOURCE_ID) REFERENCES SBI_DATA_SOURCE (DS_ID ) ON UPDATE NO ACTION ON DELETE CASCADE;

ALTER TABLE SBI_DATA_SET ADD CONSTRAINT FK_DATA_SET_CATEGORY FOREIGN KEY (CATEGORY_ID) REFERENCES SBI_DOMAINS (VALUE_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_PRODUCT_TYPE_ENGINE ADD CONSTRAINT FK_ENGINE_2 FOREIGN KEY (ENGINE_ID) REFERENCES SBI_ENGINES (ENGINE_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_FUNCTION_INPUT_DATASET ADD CONSTRAINT FK_FUNCTION_INPUT_DATASETS_2 FOREIGN KEY (FUNCTION_ID) REFERENCES SBI_CATALOG_FUNCTION (FUNCTION_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_FUNCTION_INPUT_VARIABLE ADD CONSTRAINT FK_FUNCTION_INPUT_VARIABLES_1 FOREIGN KEY (FUNCTION_ID) REFERENCES SBI_CATALOG_FUNCTION (FUNCTION_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_GEO_MAP_FEATURES ADD CONSTRAINT FK_GEO_MAP_FEATURES1 FOREIGN KEY (MAP_ID) REFERENCES SBI_GEO_MAPS (MAP_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_GEO_MAP_FEATURES ADD CONSTRAINT FK_GEO_MAP_FEATURES2 FOREIGN KEY (FEATURE_ID) REFERENCES SBI_GEO_FEATURES (FEATURE_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_ROLES_LAYERS ADD CONSTRAINT FK_ID_LAYER FOREIGN KEY (ID_LAYER) REFERENCES SBI_GEO_LAYERS (LAYER_ID ) ON UPDATE NO ACTION ON DELETE CASCADE;

ALTER TABLE SBI_ROLES_LAYERS ADD CONSTRAINT FK_ID_ROLE FOREIGN KEY (ID_ROLE) REFERENCES SBI_EXT_ROLES (EXT_ROLE_ID ) ON UPDATE NO ACTION ON DELETE CASCADE;

ALTER TABLE SBI_META_MODELS ADD CONSTRAINT FK_META_MODELS_CATEGORY FOREIGN KEY (CATEGORY_ID) REFERENCES SBI_DOMAINS (VALUE_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_ORGANIZATION_DATASOURCE ADD CONSTRAINT FK_ORGANIZATION_2 FOREIGN KEY (ORGANIZATION_ID) REFERENCES SBI_ORGANIZATIONS (ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_ORGANIZATION_PRODUCT_TYPE ADD CONSTRAINT FK_ORGANIZATION_3 FOREIGN KEY (ORGANIZATION_ID) REFERENCES SBI_ORGANIZATIONS (ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_USER_FUNC ADD CONSTRAINT FK_PRODUCT_TYPE FOREIGN KEY (PRODUCT_TYPE_ID) REFERENCES SBI_PRODUCT_TYPE (PRODUCT_TYPE_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_ORGANIZATION_PRODUCT_TYPE ADD CONSTRAINT FK_PRODUCT_TYPE_1 FOREIGN KEY (PRODUCT_TYPE_ID) REFERENCES SBI_PRODUCT_TYPE (PRODUCT_TYPE_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_PRODUCT_TYPE_ENGINE ADD CONSTRAINT FK_PRODUCT_TYPE_2 FOREIGN KEY (PRODUCT_TYPE_ID) REFERENCES SBI_PRODUCT_TYPE (PRODUCT_TYPE_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_AUTHORIZATIONS_ROLES ADD CONSTRAINT FK_ROLE1 FOREIGN KEY (ROLE_ID) REFERENCES SBI_EXT_ROLES (EXT_ROLE_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_ARTIFACTS_VERSIONS ADD CONSTRAINT FK_SBI_ARTIFACTS_VERSIONS_1 FOREIGN KEY (ARTIFACT_ID) REFERENCES SBI_ARTIFACTS (ID) ON UPDATE NO ACTION ON DELETE CASCADE;
ALTER TABLE SBI_AUDIT ADD CONSTRAINT FK_SBI_AUDIT_1 FOREIGN KEY (DOC_REF) REFERENCES SBI_OBJECTS (BIOBJ_ID) ON UPDATE NO ACTION ON DELETE SET NULL;
ALTER TABLE SBI_AUDIT ADD CONSTRAINT FK_SBI_AUDIT_2 FOREIGN KEY (ENGINE_REF) REFERENCES SBI_ENGINES (ENGINE_ID) ON UPDATE NO ACTION ON DELETE SET NULL;
ALTER TABLE SBI_AUDIT ADD CONSTRAINT FK_SBI_AUDIT_3 FOREIGN KEY (SUBOBJ_REF) REFERENCES SBI_SUBOBJECTS (SUBOBJ_ID) ON UPDATE NO ACTION ON DELETE SET NULL;
ALTER TABLE SBI_CHECKS ADD CONSTRAINT FK_SBI_CHECKS_1 FOREIGN KEY (VALUE_TYPE_ID) REFERENCES SBI_DOMAINS (VALUE_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_CONFIG ADD CONSTRAINT FK_SBI_CONFIG_1 FOREIGN KEY (VALUE_TYPE_ID) REFERENCES SBI_DOMAINS (VALUE_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_CROSS_NAVIGATION_PAR ADD CONSTRAINT FK_SBI_CROSS_NAVIGATION_PAR_1 FOREIGN KEY (CN_ID) REFERENCES SBI_CROSS_NAVIGATION (ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_DATA_SET_FEDERATION ADD CONSTRAINT FK_SBI_DATA_SET_FED_DS FOREIGN KEY (DS_ID,VERSION_NUM, ORGANIZATION) REFERENCES SBI_DATA_SET (DS_ID, VERSION_NUM, ORGANIZATION) ON UPDATE NO ACTION ON DELETE CASCADE;
ALTER TABLE SBI_DATA_SET_FEDERATION ADD CONSTRAINT FK_SBI_DATA_SET_FED_FD FOREIGN KEY (FEDERATION_ID) REFERENCES SBI_FEDERATION_DEFINITION (FEDERATION_ID) ON UPDATE NO ACTION ON DELETE CASCADE;
ALTER TABLE SBI_DATA_SOURCE ADD CONSTRAINT FK_SBI_DATA_SOURCE_1 FOREIGN KEY (DIALECT_ID) REFERENCES SBI_DOMAINS (VALUE_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_DIST_LIST_OBJECTS ADD CONSTRAINT FK_SBI_DIST_LIST_OBJECTS_1 FOREIGN KEY (DOC_ID) REFERENCES SBI_OBJECTS (BIOBJ_ID) ON UPDATE NO ACTION ON DELETE CASCADE;
ALTER TABLE SBI_DIST_LIST_OBJECTS ADD CONSTRAINT FK_SBI_DIST_LIST_OBJECTS_2 FOREIGN KEY (DL_ID) REFERENCES SBI_DIST_LIST (DL_ID) ON UPDATE NO ACTION ON DELETE CASCADE;
ALTER TABLE SBI_DIST_LIST_USER ADD CONSTRAINT FK_SBI_DIST_LIST_USER_1 FOREIGN KEY (LIST_ID) REFERENCES SBI_DIST_LIST (DL_ID) ON UPDATE NO ACTION ON DELETE CASCADE;
ALTER TABLE SBI_DATA_SET ADD CONSTRAINT FK_SBI_DOMAINS_2 FOREIGN KEY (SCOPE_ID) REFERENCES SBI_DOMAINS (VALUE_ID) ON UPDATE NO ACTION ON DELETE CASCADE;
ALTER TABLE SBI_ENGINES ADD CONSTRAINT FK_SBI_ENGINES_1 FOREIGN KEY (BIOBJ_TYPE) REFERENCES SBI_DOMAINS (VALUE_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_ENGINES ADD CONSTRAINT FK_SBI_ENGINES_2 FOREIGN KEY (ENGINE_TYPE) REFERENCES SBI_DOMAINS (VALUE_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_EVENTS_ROLES ADD CONSTRAINT FK_SBI_EVENTS_ROLES_1 FOREIGN KEY (ROLE_ID) REFERENCES SBI_EXT_ROLES (EXT_ROLE_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_EVENTS_ROLES ADD CONSTRAINT FK_SBI_EVENTS_ROLES_2 FOREIGN KEY (EVENT_ID) REFERENCES SBI_EVENTS_LOG (ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_EXPORTERS ADD CONSTRAINT FK_SBI_EXPORTERS_1 FOREIGN KEY (ENGINE_ID) REFERENCES SBI_ENGINES (ENGINE_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_EXPORTERS ADD CONSTRAINT FK_SBI_EXPORTERS_2 FOREIGN KEY (DOMAIN_ID) REFERENCES SBI_DOMAINS (VALUE_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_EXT_ROLES ADD CONSTRAINT FK_SBI_EXT_ROLES_1 FOREIGN KEY (ROLE_TYPE_ID) REFERENCES SBI_DOMAINS (VALUE_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_EXT_USER_ROLES ADD CONSTRAINT FK_SBI_EXT_USER_ROLES_1 FOREIGN KEY (ID) REFERENCES SBI_USER (ID) ON UPDATE NO ACTION ON DELETE CASCADE;
ALTER TABLE SBI_EXT_USER_ROLES ADD CONSTRAINT FK_SBI_EXT_USER_ROLES_2 FOREIGN KEY (EXT_ROLE_ID) REFERENCES SBI_EXT_ROLES (EXT_ROLE_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_DATA_SET ADD CONSTRAINT FK_SBI_FEDERATION FOREIGN KEY (FEDERATION_ID) REFERENCES SBI_FEDERATION_DEFINITION (FEDERATION_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_FUNCTIONS ADD CONSTRAINT FK_SBI_FUNCTIONS_1 FOREIGN KEY (FUNCT_TYPE_ID) REFERENCES SBI_DOMAINS (VALUE_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_FUNCTIONS ADD CONSTRAINT FK_SBI_FUNCTIONS_2 FOREIGN KEY (PARENT_FUNCT_ID) REFERENCES SBI_FUNCTIONS (FUNCT_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_FUNCTIONS_ORGANIZER ADD CONSTRAINT FK_SBI_FUNCTIONS_ORGANIZER_1 FOREIGN KEY (PARENT_FUNCT_ID) REFERENCES SBI_FUNCTIONS_ORGANIZER (FUNCT_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_FUNCTION_OUTPUT ADD CONSTRAINT FK_SBI_FUNCTION_OUTPUT_1 FOREIGN KEY (OUT_TYPE) REFERENCES SBI_DOMAINS (VALUE_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_FUNCTION_OUTPUT ADD CONSTRAINT FK_SBI_FUNCTION_OUTPUT_2 FOREIGN KEY (FUNCTION_ID) REFERENCES SBI_CATALOG_FUNCTION (FUNCTION_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_FUNC_ROLE ADD CONSTRAINT FK_SBI_FUNC_ROLE_1 FOREIGN KEY (ROLE_ID) REFERENCES SBI_EXT_ROLES (EXT_ROLE_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_FUNC_ROLE ADD CONSTRAINT FK_SBI_FUNC_ROLE_2 FOREIGN KEY (STATE_ID) REFERENCES SBI_DOMAINS (VALUE_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_FUNC_ROLE ADD CONSTRAINT FK_SBI_FUNC_ROLE_3 FOREIGN KEY (FUNCT_ID) REFERENCES SBI_FUNCTIONS (FUNCT_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_GEO_MAPS ADD CONSTRAINT FK_SBI_GEO_MAPS_1 FOREIGN KEY (BIN_ID) REFERENCES SBI_BINARY_CONTENTS (BIN_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_I18N_MESSAGES ADD CONSTRAINT FK_SBI_I18N_MESSAGES FOREIGN KEY (LANGUAGE_CD) REFERENCES SBI_DOMAINS (VALUE_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_LOV ADD CONSTRAINT FK_SBI_LOV_1 FOREIGN KEY (INPUT_TYPE_ID) REFERENCES SBI_DOMAINS (VALUE_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_MENU_ROLE ADD CONSTRAINT FK_SBI_MENU_ROLE1 FOREIGN KEY (MENU_ID) REFERENCES SBI_MENU (MENU_ID) ON UPDATE NO ACTION ON DELETE CASCADE;
ALTER TABLE SBI_MENU_ROLE ADD CONSTRAINT FK_SBI_MENU_ROLE2 FOREIGN KEY (EXT_ROLE_ID) REFERENCES SBI_EXT_ROLES (EXT_ROLE_ID) ON UPDATE NO ACTION ON DELETE CASCADE;
ALTER TABLE SBI_META_BC ADD CONSTRAINT FK_SBI_META_BC_1 FOREIGN KEY (MODEL_ID) REFERENCES SBI_META_MODELS (ID) ON UPDATE NO ACTION ON DELETE CASCADE;

ALTER TABLE SBI_META_BC_ATTRIBUTE ADD CONSTRAINT FK_SBI_META_BC_ATTRIBUTE_1 FOREIGN KEY (BC_ID) REFERENCES SBI_META_BC (BC_ID) ON UPDATE NO ACTION ON DELETE CASCADE;

ALTER TABLE SBI_META_BC_ATTRIBUTE ADD CONSTRAINT FK_SBI_META_BC_ATTRIBUTE_2 FOREIGN KEY (COLUMN_ID) REFERENCES SBI_META_TABLE_COLUMN (COLUMN_ID) ON UPDATE NO ACTION ON DELETE CASCADE;

ALTER TABLE SBI_META_TABLE_COLUMN ADD CONSTRAINT FK_SBI_META_COLUMN_1 FOREIGN KEY (TABLE_ID) REFERENCES SBI_META_TABLE (TABLE_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_META_DS_BC ADD CONSTRAINT FK_SBI_META_DS_BC_1 FOREIGN KEY (DS_ID, VERSION_NUM, ORGANIZATION) REFERENCES SBI_DATA_SET (DS_ID, VERSION_NUM, ORGANIZATION) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_META_DS_BC ADD CONSTRAINT FK_SBI_META_DS_BC_2 FOREIGN KEY (BC_ID) REFERENCES SBI_META_BC (BC_ID) ON UPDATE NO ACTION ON DELETE CASCADE;

ALTER TABLE SBI_META_JOB_SOURCE ADD CONSTRAINT FK_SBI_META_JOB_SOURCE_1 FOREIGN KEY (JOB_ID) REFERENCES SBI_META_JOB (JOB_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_META_JOB_SOURCE ADD CONSTRAINT FK_SBI_META_JOB_SOURCE_2 FOREIGN KEY (SOURCE_ID) REFERENCES SBI_META_SOURCE (SOURCE_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_META_JOB_TABLE ADD CONSTRAINT FK_SBI_META_JOB_TABLE_1 FOREIGN KEY (JOB_ID) REFERENCES SBI_META_JOB (JOB_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_META_JOB_TABLE ADD CONSTRAINT FK_SBI_META_JOB_TABLE_2 FOREIGN KEY (TABLE_ID) REFERENCES SBI_META_TABLE (TABLE_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_META_MODELS_VERSIONS ADD CONSTRAINT FK_SBI_META_MODELS_VERSIONS_1 FOREIGN KEY (MODEL_ID) REFERENCES SBI_META_MODELS (ID) ON UPDATE NO ACTION ON DELETE CASCADE;
ALTER TABLE SBI_META_OBJ_DS ADD CONSTRAINT FK_SBI_META_OBJ_DS_1 FOREIGN KEY (DS_ID, VERSION_NUM, ORGANIZATION) REFERENCES SBI_DATA_SET (DS_ID, VERSION_NUM, ORGANIZATION) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_META_OBJ_DS ADD CONSTRAINT FK_SBI_META_OBJ_DS_2 FOREIGN KEY (OBJ_ID) REFERENCES SBI_OBJECTS (BIOBJ_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_META_TABLE ADD CONSTRAINT FK_SBI_META_TABLE_1 FOREIGN KEY (SOURCE_ID) REFERENCES SBI_META_SOURCE (SOURCE_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_META_TABLE_BC ADD CONSTRAINT FK_SBI_META_TABLE_BC_1 FOREIGN KEY (TABLE_ID) REFERENCES SBI_META_TABLE (TABLE_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_META_TABLE_BC ADD CONSTRAINT FK_SBI_META_TABLE_BC_2 FOREIGN KEY (BC_ID) REFERENCES SBI_META_BC (BC_ID) ON UPDATE NO ACTION ON DELETE CASCADE;

ALTER TABLE SBI_OBJECTS ADD CONSTRAINT FK_SBI_OBJECTS_1 FOREIGN KEY (STATE_CONS_ID) REFERENCES SBI_DOMAINS (VALUE_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_OBJECTS ADD CONSTRAINT FK_SBI_OBJECTS_2 FOREIGN KEY (STATE_ID) REFERENCES SBI_DOMAINS (VALUE_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_OBJECTS ADD CONSTRAINT FK_SBI_OBJECTS_3 FOREIGN KEY (BIOBJ_TYPE_ID) REFERENCES SBI_DOMAINS (VALUE_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_OBJECTS ADD CONSTRAINT FK_SBI_OBJECTS_4 FOREIGN KEY (EXEC_MODE_ID) REFERENCES SBI_DOMAINS (VALUE_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_OBJECTS ADD CONSTRAINT FK_SBI_OBJECTS_5 FOREIGN KEY (ENGINE_ID) REFERENCES SBI_ENGINES (ENGINE_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_OBJECTS_RATING ADD CONSTRAINT FK_SBI_OBJECTS_RATING_1 FOREIGN KEY (OBJ_ID) REFERENCES SBI_OBJECTS (BIOBJ_ID) ON UPDATE CASCADE ON DELETE CASCADE;
ALTER TABLE SBI_OBJECT_NOTES ADD CONSTRAINT FK_SBI_OBJECT_NOTES_1 FOREIGN KEY (BIN_ID) REFERENCES SBI_BINARY_CONTENTS (BIN_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_OBJECT_NOTES ADD CONSTRAINT FK_SBI_OBJECT_NOTES_2 FOREIGN KEY (BIOBJ_ID) REFERENCES SBI_OBJECTS (BIOBJ_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_OBJECT_TEMPLATES ADD CONSTRAINT FK_SBI_OBJECT_TEMPLATES_1 FOREIGN KEY (BIN_ID) REFERENCES SBI_BINARY_CONTENTS (BIN_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_OBJECT_TEMPLATES ADD CONSTRAINT FK_SBI_OBJECT_TEMPLATES_2 FOREIGN KEY (BIOBJ_ID) REFERENCES SBI_OBJECTS (BIOBJ_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_OBJ_DATA_SET ADD CONSTRAINT FK_SBI_OBJ_DATA_SET_1 FOREIGN KEY (BIOBJ_ID) REFERENCES SBI_OBJECTS (BIOBJ_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_OBJ_FUNC ADD CONSTRAINT FK_SBI_OBJ_FUNC_1 FOREIGN KEY (FUNCT_ID) REFERENCES SBI_FUNCTIONS (FUNCT_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_OBJ_FUNC ADD CONSTRAINT FK_SBI_OBJ_FUNC_2 FOREIGN KEY (BIOBJ_ID) REFERENCES SBI_OBJECTS (BIOBJ_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_OBJ_FUNC_ORGANIZER ADD CONSTRAINT FK_SBI_OBJ_FUNC_ORGANIZER_1 FOREIGN KEY (FUNCT_ID) REFERENCES SBI_FUNCTIONS_ORGANIZER (FUNCT_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_OBJ_FUNC_ORGANIZER ADD CONSTRAINT FK_SBI_OBJ_FUNC_ORGANIZER_2 FOREIGN KEY (BIOBJ_ID) REFERENCES SBI_OBJECTS (BIOBJ_ID) ON UPDATE CASCADE ON DELETE CASCADE;
ALTER TABLE SBI_OBJ_METACONTENTS ADD CONSTRAINT FK_SBI_OBJ_METACONTENTS_1 FOREIGN KEY (OBJMETA_ID) REFERENCES SBI_OBJ_METADATA (OBJ_META_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_OBJ_METACONTENTS ADD CONSTRAINT FK_SBI_OBJ_METACONTENTS_2 FOREIGN KEY (BIOBJ_ID) REFERENCES SBI_OBJECTS (BIOBJ_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_OBJ_METACONTENTS ADD CONSTRAINT FK_SBI_OBJ_METACONTENTS_3 FOREIGN KEY (SUBOBJ_ID) REFERENCES SBI_SUBOBJECTS (SUBOBJ_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_OBJ_METACONTENTS ADD CONSTRAINT FK_SBI_OBJ_METACONTENTS_4 FOREIGN KEY (BIN_ID) REFERENCES SBI_BINARY_CONTENTS (BIN_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_OBJ_METADATA ADD CONSTRAINT FK_SBI_OBJ_METADATA_1 FOREIGN KEY (DATA_TYPE_ID) REFERENCES SBI_DOMAINS (VALUE_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_OBJ_PARUSE ADD CONSTRAINT FK_SBI_OBJ_PARUSE_1 FOREIGN KEY (OBJ_PAR_ID) REFERENCES SBI_OBJ_PAR (OBJ_PAR_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_OBJ_PARUSE ADD CONSTRAINT FK_SBI_OBJ_PARUSE_2 FOREIGN KEY (USE_ID) REFERENCES SBI_PARUSE (USE_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_OBJ_PARUSE ADD CONSTRAINT FK_SBI_OBJ_PARUSE_3 FOREIGN KEY (OBJ_PAR_FATHER_ID) REFERENCES SBI_OBJ_PAR (OBJ_PAR_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_OBJ_PARVIEW ADD CONSTRAINT FK_SBI_OBJ_PARVIEW_1 FOREIGN KEY (OBJ_PAR_ID) REFERENCES SBI_OBJ_PAR (OBJ_PAR_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_OBJ_PARVIEW ADD CONSTRAINT FK_SBI_OBJ_PARVIEW_2 FOREIGN KEY (OBJ_PAR_FATHER_ID) REFERENCES SBI_OBJ_PAR (OBJ_PAR_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_OBJ_PAR ADD CONSTRAINT FK_SBI_OBJ_PAR_1 FOREIGN KEY (BIOBJ_ID) REFERENCES SBI_OBJECTS (BIOBJ_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_OBJ_PAR ADD CONSTRAINT FK_SBI_OBJ_PAR_2 FOREIGN KEY (PAR_ID) REFERENCES SBI_PARAMETERS (PAR_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_OBJ_STATE ADD CONSTRAINT FK_SBI_OBJ_STATE_1 FOREIGN KEY (BIOBJ_ID) REFERENCES SBI_OBJECTS (BIOBJ_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_OBJ_STATE ADD CONSTRAINT FK_SBI_OBJ_STATE_2 FOREIGN KEY (STATE_ID) REFERENCES SBI_DOMAINS (VALUE_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_OUTPUT_PARAMETER ADD CONSTRAINT FK_SBI_OUTPUT_PARAMETER_1 FOREIGN KEY (BIOBJ_ID) REFERENCES SBI_OBJECTS (BIOBJ_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_OUTPUT_PARAMETER ADD CONSTRAINT FK_SBI_OUTPUT_PARAMETER_2 FOREIGN KEY (PAR_TYPE_ID) REFERENCES SBI_DOMAINS (VALUE_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_PARAMETERS ADD CONSTRAINT FK_SBI_PARAMETERS_1 FOREIGN KEY (PAR_TYPE_ID) REFERENCES SBI_DOMAINS (VALUE_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_PARUSE ADD CONSTRAINT FK_SBI_PARUSE_1 FOREIGN KEY (PAR_ID) REFERENCES SBI_PARAMETERS (PAR_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_PARUSE ADD CONSTRAINT FK_SBI_PARUSE_2 FOREIGN KEY (LOV_ID) REFERENCES SBI_LOV (LOV_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_PARUSE ADD CONSTRAINT FK_SBI_PARUSE_3 FOREIGN KEY (DEFAULT_LOV_ID) REFERENCES SBI_LOV (LOV_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_PARUSE_CK ADD CONSTRAINT FK_SBI_PARUSE_CK_1 FOREIGN KEY (USE_ID) REFERENCES SBI_PARUSE (USE_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_PARUSE_CK ADD CONSTRAINT FK_SBI_PARUSE_CK_2 FOREIGN KEY (CHECK_ID) REFERENCES SBI_CHECKS (CHECK_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_PARUSE_DET ADD CONSTRAINT FK_SBI_PARUSE_DET_1 FOREIGN KEY (USE_ID) REFERENCES SBI_PARUSE (USE_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_PARUSE_DET ADD CONSTRAINT FK_SBI_PARUSE_DET_2 FOREIGN KEY (EXT_ROLE_ID) REFERENCES SBI_EXT_ROLES (EXT_ROLE_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_REMEMBER_ME ADD CONSTRAINT FK_SBI_REMEMBER_ME_1 FOREIGN KEY (BIOBJ_ID) REFERENCES SBI_OBJECTS (BIOBJ_ID) ON UPDATE NO ACTION ON DELETE CASCADE;
ALTER TABLE SBI_REMEMBER_ME ADD CONSTRAINT FK_SBI_REMEMBER_ME_2 FOREIGN KEY (SUBOBJ_ID) REFERENCES SBI_SUBOBJECTS (SUBOBJ_ID) ON UPDATE NO ACTION ON DELETE CASCADE;
ALTER TABLE SBI_ROLE_TYPE_USER_FUNC ADD CONSTRAINT FK_SBI_ROLE_TYPE_USER_FUNC_1 FOREIGN KEY (ROLE_TYPE_ID) REFERENCES SBI_DOMAINS (VALUE_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_ROLE_TYPE_USER_FUNC ADD CONSTRAINT FK_SBI_ROLE_TYPE_USER_FUNC_2 FOREIGN KEY (USER_FUNCT_ID) REFERENCES SBI_USER_FUNC (USER_FUNCT_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_UDP ADD CONSTRAINT FK_SBI_SBI_UDP_1 FOREIGN KEY (TYPE_ID) REFERENCES SBI_DOMAINS (VALUE_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_UDP ADD CONSTRAINT FK_SBI_SBI_UDP_2 FOREIGN KEY (FAMILY_ID) REFERENCES SBI_DOMAINS (VALUE_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_SNAPSHOTS ADD CONSTRAINT FK_SBI_SNAPSHOTS_1 FOREIGN KEY (BIN_ID) REFERENCES SBI_BINARY_CONTENTS (BIN_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_SNAPSHOTS ADD CONSTRAINT FK_SBI_SNAPSHOTS_2 FOREIGN KEY (BIOBJ_ID) REFERENCES SBI_OBJECTS (BIOBJ_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_SUBOBJECTS ADD CONSTRAINT FK_SBI_SUBOBJECTS_1 FOREIGN KEY (BIN_ID) REFERENCES SBI_BINARY_CONTENTS (BIN_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_SUBOBJECTS ADD CONSTRAINT FK_SBI_SUBOBJECTS_2 FOREIGN KEY (BIOBJ_ID) REFERENCES SBI_OBJECTS (BIOBJ_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_SUBREPORTS ADD CONSTRAINT FK_SBI_SUBREPORTS_1 FOREIGN KEY (MASTER_RPT_ID) REFERENCES SBI_OBJECTS (BIOBJ_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_SUBREPORTS ADD CONSTRAINT FK_SBI_SUBREPORTS_2 FOREIGN KEY (SUB_RPT_ID) REFERENCES SBI_OBJECTS (BIOBJ_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_UDP_VALUE ADD CONSTRAINT FK_SBI_UDP_VALUE_2 FOREIGN KEY (UDP_ID) REFERENCES SBI_UDP (UDP_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_USER_ATTRIBUTES ADD CONSTRAINT FK_SBI_USER_ATTRIBUTES_1 FOREIGN KEY (ID) REFERENCES SBI_USER (ID) ON UPDATE NO ACTION ON DELETE CASCADE;
ALTER TABLE SBI_USER_ATTRIBUTES ADD CONSTRAINT FK_SBI_USER_ATTRIBUTES_2 FOREIGN KEY (ATTRIBUTE_ID) REFERENCES SBI_ATTRIBUTE (ATTRIBUTE_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_VIEWPOINTS ADD CONSTRAINT FK_SBI_VIEWPOINTS_1 FOREIGN KEY (BIOBJ_ID) REFERENCES SBI_OBJECTS (BIOBJ_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_EXT_ROLES_CATEGORY ADD CONSTRAINT FK_SB_EXT_ROLES_META_MODEL_CATEGORY_1 FOREIGN KEY (EXT_ROLE_ID) REFERENCES SBI_EXT_ROLES (EXT_ROLE_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_EXT_ROLES_CATEGORY ADD CONSTRAINT FK_SB_EXT_ROLES_META_MODEL_CATEGORY_2 FOREIGN KEY (CATEGORY_ID) REFERENCES SBI_DOMAINS (VALUE_ID) ON UPDATE NO ACTION ON DELETE NO ACTION;

ALTER TABLE SBI_WHATIF_WORKFLOW 				ADD CONSTRAINT FK_SBI_MODEL_WORKFLOW			FOREIGN KEY (MODEL_ID) 			REFERENCES SBI_ARTIFACTS(ID)	ON DELETE CASCADE ON UPDATE NO ACTION;
ALTER TABLE SBI_WHATIF_WORKFLOW 				ADD CONSTRAINT FK_SBI_USER_WORKFLOW			FOREIGN KEY (USER_ID) 				REFERENCES SBI_USER(ID) ON DELETE CASCADE ON UPDATE NO ACTION;

-- Workaround to fix lock problem on initialization of metadata tables (in SQL SERVER)
INSERT INTO SBI_ORGANIZATIONS (ID, NAME) VALUES (1, 'DEFAULT_TENANT');
ALTER TABLE SBI_META_MODELS ADD CONSTRAINT FK_META_MODELS_DS_ID FOREIGN KEY (DATA_SOURCE_ID) REFERENCES SBI_DATA_SOURCE(DS_ID) ON DELETE CASCADE ON UPDATE NO ACTION;

ALTER TABLE SBI_DOSSIER_ACTIVITY ADD CONSTRAINT FK_SBI_PROGRESS_THREAD	FOREIGN KEY (PROGRESS) 	REFERENCES SBI_PROGRESS_THREAD(PROGRESS_THREAD_ID)			ON DELETE CASCADE ON UPDATE CASCADE;
ALTER TABLE SBI_DOSSIER_ACTIVITY ADD CONSTRAINT FK_SBI_OBJECTS FOREIGN KEY  (DOCUMENT_ID) REFERENCES SBI_OBJECTS (BIOBJ_ID) ON DELETE CASCADE ON UPDATE CASCADE;
